==> jc-1.4.0.tar.gz: java/beans/BeanDescriptor.h <==
// public class java.beans.BeanDescriptor

// class file dependencies
// @dep_class 3609311876953c34 java_beans_BeanDescriptor
// @dep_class 171fda3bb37b43ab java_beans_FeatureDescriptor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_FeatureDescriptor

#include "java/beans/FeatureDescriptor.h"

#ifndef _JC_java_beans_BeanDescriptor_H_
#define _JC_java_beans_BeanDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_BeanDescriptor$sub_refs	_jc_java_beans_BeanDescriptor$sub_refs;
typedef struct _jc_java_beans_BeanDescriptor$sub_nonrefs	_jc_java_beans_BeanDescriptor$sub_nonrefs;
typedef struct _jc_java_beans_BeanDescriptor$refs	_jc_java_beans_BeanDescriptor$refs;
typedef struct _jc_java_beans_BeanDescriptor$nonrefs	_jc_java_beans_BeanDescriptor$nonrefs;
typedef struct _jc_java_beans_BeanDescriptor$object	_jc_java_beans_BeanDescriptor$object;

typedef const struct _jc_java_beans_BeanDescriptor$vmethods	_jc_java_beans_BeanDescriptor$vmethods;
typedef const struct _jc_java_beans_BeanDescriptor$vtable	_jc_java_beans_BeanDescriptor$vtable;
typedef const struct _jc_java_beans_BeanDescriptor$vtype	_jc_java_beans_BeanDescriptor$vtype;

// Constructors
extern void _jc_java_beans_BeanDescriptor$method$_init$288d3bcb8f0d1932(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *, struct _jc_java_lang_Class$object *);
extern void _jc_java_beans_BeanDescriptor$method$_init$1022fe2092fb5155(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_beans_BeanDescriptor$method$getBeanClass$96d497761ce25c29(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *);
extern struct _jc_java_lang_Class$object *_jc_java_beans_BeanDescriptor$method$getCustomizerClass$d1862afc4e5d232e(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_BeanDescriptor$method_info$getBeanClass$96d497761ce25c29;
extern _jc_method _jc_java_beans_BeanDescriptor$method_info$getCustomizerClass$d1862afc4e5d232e;

// Virtual methods structure
struct _jc_java_beans_BeanDescriptor$vmethods {
	struct _jc_java_lang_Class$object	*(*getBeanClass$96d497761ce25c29)(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *);
	struct _jc_java_lang_Class$object	*(*getCustomizerClass$d1862afc4e5d232e)(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *);
};

// Vtable
struct _jc_java_beans_BeanDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_FeatureDescriptor$vmethods	java_beans_FeatureDescriptor;
	_jc_java_beans_BeanDescriptor$vmethods	java_beans_BeanDescriptor;
};

// Vtype
struct _jc_java_beans_BeanDescriptor$vtype {
	_jc_type			type;
	_jc_java_beans_BeanDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_BeanDescriptor$sub_refs {
	struct _jc_java_lang_Class$object	*beanClass;
	struct _jc_java_lang_Class$object	*customizerClass;
};

// Reference instance fields (object)
struct _jc_java_beans_BeanDescriptor$refs {
    _jc_java_beans_BeanDescriptor$sub_refs	java_beans_BeanDescriptor;
    _jc_java_beans_FeatureDescriptor$sub_refs	java_beans_FeatureDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_BeanDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_BeanDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_FeatureDescriptor$sub_nonrefs	java_beans_FeatureDescriptor;
    _jc_java_beans_BeanDescriptor$sub_nonrefs	java_beans_BeanDescriptor;
};

// Object instance structure
struct _jc_java_beans_BeanDescriptor$object {
	_jc_java_beans_BeanDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_BeanDescriptor$vtype	*vtype;
	_jc_java_beans_BeanDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_BeanDescriptor$vtype _jc_java_beans_BeanDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_BeanDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_BeanDescriptor$class_object;

#endif	/* _JC_java_beans_BeanDescriptor_H_ */

==> jc-1.4.6.tar.gz: java/beans/BeanDescriptor.h <==
// public class java.beans.BeanDescriptor

// class file dependencies
// @dep_class 3609311876953c34 java_beans_BeanDescriptor
// @dep_class 8327659df0b02789 java_beans_FeatureDescriptor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_FeatureDescriptor

#include "java/beans/FeatureDescriptor.h"

#ifndef _JC_java_beans_BeanDescriptor_H_
#define _JC_java_beans_BeanDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_BeanDescriptor$sub_refs	_jc_java_beans_BeanDescriptor$sub_refs;
typedef struct _jc_java_beans_BeanDescriptor$sub_nonrefs	_jc_java_beans_BeanDescriptor$sub_nonrefs;
typedef struct _jc_java_beans_BeanDescriptor$refs	_jc_java_beans_BeanDescriptor$refs;
typedef struct _jc_java_beans_BeanDescriptor$nonrefs	_jc_java_beans_BeanDescriptor$nonrefs;
typedef struct _jc_java_beans_BeanDescriptor$object	_jc_java_beans_BeanDescriptor$object;

typedef const struct _jc_java_beans_BeanDescriptor$vmethods	_jc_java_beans_BeanDescriptor$vmethods;
typedef const struct _jc_java_beans_BeanDescriptor$vtable	_jc_java_beans_BeanDescriptor$vtable;
typedef const struct _jc_java_beans_BeanDescriptor$vtype	_jc_java_beans_BeanDescriptor$vtype;

// Constructors
extern void _jc_java_beans_BeanDescriptor$method$_init$288d3bcb8f0d1932(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_BeanDescriptor$method$_init$1022fe2092fb5155(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_beans_BeanDescriptor$method$getBeanClass$96d497761ce25c29(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_beans_BeanDescriptor$method$getCustomizerClass$d1862afc4e5d232e(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_BeanDescriptor$method_info$getBeanClass$96d497761ce25c29;
extern _jc_method _jc_java_beans_BeanDescriptor$method_info$getCustomizerClass$d1862afc4e5d232e;

// Virtual methods structure
struct _jc_java_beans_BeanDescriptor$vmethods {
	struct _jc_java_lang_Class$object	*(*getBeanClass$96d497761ce25c29)(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCustomizerClass$d1862afc4e5d232e)(_jc_env *, struct _jc_java_beans_BeanDescriptor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_BeanDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_FeatureDescriptor$vmethods	java_beans_FeatureDescriptor;
	_jc_java_beans_BeanDescriptor$vmethods	java_beans_BeanDescriptor;
};

// Vtype
struct _jc_java_beans_BeanDescriptor$vtype {
	_jc_type			type;
	_jc_java_beans_BeanDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_BeanDescriptor$sub_refs {
	struct _jc_java_lang_Class$object	*beanClass;
	struct _jc_java_lang_Class$object	*customizerClass;
};

// Reference instance fields (object)
struct _jc_java_beans_BeanDescriptor$refs {
    _jc_java_beans_BeanDescriptor$sub_refs	java_beans_BeanDescriptor;
    _jc_java_beans_FeatureDescriptor$sub_refs	java_beans_FeatureDescriptor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_BeanDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_BeanDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_FeatureDescriptor$sub_nonrefs	java_beans_FeatureDescriptor;
    _jc_java_beans_BeanDescriptor$sub_nonrefs	java_beans_BeanDescriptor;
};

// Object instance structure
struct _jc_java_beans_BeanDescriptor$object {
	_jc_java_beans_BeanDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_BeanDescriptor$vtype	*vtype;
	_jc_java_beans_BeanDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_BeanDescriptor$vtype _jc_java_beans_BeanDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_BeanDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_BeanDescriptor$class_object;

#endif	/* _JC_java_beans_BeanDescriptor_H_ */
